@@ -74,7 +74,7 @@ def output(eds, reversion_eds, values):
                     else:
                         # Regardless of where cursor is, is moved to the
                         # next record
-                        record = record + '\n'
+                        record = record + config.RECORD_SEPARATOR
                         state['position'] = len(record)
                         tmp_reversion_eds = reversion_eds[::-1]
             else:
@@ -157,7 +157,7 @@ def output(eds, reversion_eds, values):
             elif isinstance(ed, Colon):
                 state['halt_if_no_vals'] = True
             elif isinstance(ed, Slash):
-                state['position'], record = _write_string(record, '\n', state['position'])
+                state['position'], record = _write_string(record, config.RECORD_SEPARATOR, state['position'])
             elif isinstance(ed, (X, TR)):
                 state['position'] = state['position'] + ed.num_chars
             elif isinstance(ed, TL):
@@ -287,11 +287,9 @@ def _compose_float_string(w, e, d, state, val, ftype):
         nb = 0
         save_scale_factor = state['scale']
         exp_d = 10 ** d
-        if (0.0 < tmp < (0.1 - 0.05 / exp_d)) or \
+        if (0.0 <= tmp < (0.1 - 0.05 / exp_d)) or \
             (tmp >= (exp_d - 0.5)):
             ftype = 'E'
-        elif tmp == 0.0:
-            pass
         else:
             mag = int(abs(round(math.log10(tmp))))
             low = lambda mag, d : 10 ** (mag - 1) - 5 * 10 ** (-d - 1 + mag) 
